==> nextcloud-app-news-1:25.3.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ast.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "La solicitú falló, la conexón a la rede nun ta disponible.",
    "Request forbidden. Are you an administrator?" : "Prohibióse l'autorización. ¿Yes alministrador?",
    "Token expired or app not enabled! Reload the page!" : "El pase caducó o nun s'autorizó l'aplicación. ¡Anueva la páxina!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Hebo un error internu del sirvidor! Comprueba'l ficheru data/nextcloud.log pa consiguir más información.",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "La solicitú falló. ¡Nextcloud ta nel mou caltenimientu!",
    "News feeds" : "Feeds de noticies",
    "Unread articles" : "Artículos ensin lleer",
    "News" : "Noticies",
    "News folders" : "Carpetes de noticies",
    "News articles" : "Artículos de noticies",
    "Shared with me" : "Compartióse conmigo",
    "An RSS/Atom feed reader" : "Un llector de ficheros RSS/Atom",
    "Download" : "Baxar",
    "Close" : "Zarrar",
    "Web address" : "Direición web",
    "No folder" : "Nun hai nenguna carpeta",
    "Folder name" : "Nome de la carpeta",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡El feed yá esiste!",
    "New folder" : "Carpeta nueva",
    "Folder exists already!" : "¡La carpeta yá esiste!",
    "Subscribe" : "Soscribise",
    "Successfully updated news configuration" : "La configuración de les noticies anovóse correutamente",
    "Unable to update news config" : "Nun ye posible anovar la configuración de les noticies",
    "Last job ran {relativeTime}." : "L'últimu trabayu executó {relativeTime}.",
    "Maximum redirects" : "Redireiciones máximes",
    "Explore Service URL" : "URL del serviciu d'esploración",
    "Update interval" : "Intervalu d'anovamientu",
    "Use system cron for updates" : "Usar el cron del sistema pa los anovamientos",
    "No article selected" : "Nun se seleicionó nengún artículu",
    "Please select an article from the list..." : "Seleiciona un artículu de la llista…",
    "Move" : "Mover",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Default" : "Por defeutu",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Non",
    "Rename Folder" : "Renomar la carpeta",
    "All articles" : "Tolos artículos",
    "Explore" : "Esplorar",
    "Settings" : "Configuración",
    "Documentation" : "Documentación",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Show all articles" : "Amosar tolos artículos",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Rename Feed" : "Renomar el feed",
    "Open Feed URL" : "Abrir l'URL del feed",
    "Unpin from top" : "Lliberar",
    "Pin to top" : "Fixar no cimero",
    "Newest first" : "Primero lo nuevo",
    "Oldest first" : "Primero lo antiguo",
    "Default order" : "Orde predetermináu",
    "Enable full text" : "Activar el testu completu",
    "Disable full text" : "Desactivar el testu completu",
    "Ignore updated" : "Inorar lo anovao",
    "Previous" : "Anterior",
    "Next" : "Siguiente",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproducir l'audiu",
    "Download audio" : "Baxar l'audiu",
    "Download video" : "Baxar el videu",
    "{num} seconds" : "{num} segundos",
    "{num} minutes ago" : "hai {num} minutos",
    "{num} hours ago" : "hai {num} hores",
    "{num} days ago" : "hai {num} díes",
    "{num} months ago" : "hai {num} meses",
    "{num} years ago" : "hai {num} años",
    "Open website" : "Abrir el sitiu web",
    "Not available" : "Nun ta disponible",
    "Title" : "Títulu",
    "Keyboard shortcut" : "Atayos del tecláu",
    "Action" : "Aición",
    "Refresh" : "Anovar",
    "Load next feed" : "Cargar el feed siguiente",
    "Load previous feed" : "Cargar el feed anterior",
    "Load previous folder" : "Cargar la carpeta anterior",
    "Load next folder" : "Cargar la carpeta siguiente",
    "All Articles" : "Tolos artículos",
    "Subscribe to" : "Soscribise a",
    "Unread Articles" : "Artículos ensin lleer",
    "If given, this service" : "Si s'apurre, esti serviciu",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu",
    "No articles available" : "Nun hai nengún artículu disponible",
    "No unread articles available" : "Nun hai nengún artículu ensin lleer disponible",
    "No users found" : "Nun s'atopó nengún usuariu",
    "Error while searching for users" : "Hebo un error mentanto se buscaben usuarios",
    "Share on social media" : "Compartir el redes sociales",
    "I wanted you to see this article" : "Quiero ver esti artículu",
    "Description" : "Descripción",
    "Folder" : "Carpeta",
    "Go back" : "Dir p'atrás",
    "New Folder" : "Carpeta nueva",
    "Create" : "Crear",
    "Menu" : "Menú",
    "Open feed URL" : "Abrir l'URL del feed",
    "Dismiss" : "Escartar",
    "Collapse" : "Recoyer",
    "Compact view" : "Vista compauta",
    "Subscriptions (OPML)" : "Soscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Esportar",
    "Help" : "Ayuda",
    "Report a bug" : "Informar d'un fallju"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1:26.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/ast.js <==
OC.L10N.register(
    "news",
    {
    "News feeds" : "Feeds de noticies",
    "Unread articles" : "Artículos ensin lleer",
    "News" : "Noticies",
    "News folders" : "Carpetes de noticies",
    "News articles" : "Artículos de noticies",
    "Shared with me" : "Compartióse conmigo",
    "An RSS/Atom feed reader" : "Un llector de ficheros RSS/Atom",
    "Download" : "Baxar",
    "Close" : "Zarrar",
    "Web address" : "Direición web",
    "No folder" : "Nun hai nenguna carpeta",
    "Folder name" : "Nome de la carpeta",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡El feed yá esiste!",
    "New folder" : "Carpeta nueva",
    "Folder exists already!" : "¡La carpeta yá esiste!",
    "Subscribe" : "Soscribise",
    "Successfully updated news configuration" : "La configuración de les noticies anovóse correutamente",
    "Unable to update news config" : "Nun ye posible anovar la configuración de les noticies",
    "Last job ran {relativeTime}." : "L'últimu trabayu executó {relativeTime}.",
    "Maximum redirects" : "Redireiciones máximes",
    "Explore Service URL" : "URL del serviciu d'esploración",
    "Update interval" : "Intervalu d'anovamientu",
    "Use system cron for updates" : "Usar el cron del sistema pa los anovamientos",
    "No article selected" : "Nun se seleicionó nengún artículu",
    "Please select an article from the list..." : "Seleiciona un artículu de la llista…",
    "Move" : "Mover",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Default" : "Por defeutu",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Non",
    "Rename Folder" : "Renomar la carpeta",
    "All articles" : "Tolos artículos",
    "Explore" : "Esplorar",
    "Settings" : "Configuración",
    "Documentation" : "Documentación",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Show all articles" : "Amosar tolos artículos",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Rename Feed" : "Renomar el feed",
    "Open Feed URL" : "Abrir l'URL del feed",
    "Unpin from top" : "Lliberar",
    "Pin to top" : "Fixar no cimero",
    "Newest first" : "Primero lo nuevo",
    "Oldest first" : "Primero lo antiguo",
    "Default order" : "Orde predetermináu",
    "Enable full text" : "Activar el testu completu",
    "Disable full text" : "Desactivar el testu completu",
    "Previous" : "Anterior",
    "Next" : "Siguiente",
    "by" : "por",
    "Play audio" : "Reproducir l'audiu",
    "Download audio" : "Baxar l'audiu",
    "Download video" : "Baxar el videu",
    "Open website" : "Abrir el sitiu web",
    "Not available" : "Nun ta disponible",
    "Please wait" : "Espera",
    "Title" : "Títulu",
    "Keyboard shortcut" : "Atayos del tecláu",
    "Action" : "Aición",
    "Refresh" : "Anovar",
    "Load next feed" : "Cargar el feed siguiente",
    "Load previous feed" : "Cargar el feed anterior",
    "Load previous folder" : "Cargar la carpeta anterior",
    "Load next folder" : "Cargar la carpeta siguiente",
    "All Articles" : "Tolos artículos",
    "Subscribe to" : "Soscribise a",
    "Unread Articles" : "Artículos ensin lleer",
    "If given, this service" : "Si s'apurre, esti serviciu",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu"
},
"nplurals=2; plural=(n != 1);");
